**Example 1: 导入其它产品的数据模板**



Input: 

```
tccli iotvideo ImportModelDefinition --cli-unfold-argument  \
    --ModelSchema {} \
    --ProductId TDCZ2WD29Z
```

Output: 
```
{
    "Response": {
        "RequestId": "d8de3a44"
    }
}
```

